@@ -401,20 +401,30 @@ class OCRInsightsPredictorResource:
 
 
 class CategoryPredictorResource:
-    def on_get(self, req: falcon.Request, resp: falcon.Response):
-        barcode = req.get_param("barcode", required=True)
-        deepest_only = req.get_param_as_bool("deepest_only", default=False)
+    @jsonschema.validate(schema.PREDICT_CATEGORY_SCHEMA)
+    def on_post(self, req: falcon.Request, resp: falcon.Response):
+        """Predict categories using neural categorizer for a specific product."""
+        if "barcode" in req.media:
+            # Fetch product from DB
+            barcode: str = req.media["barcode"]
+            product = get_product(barcode, fields=["product_name", "ingredients_tags"])
+        else:
+            product = req.media["product"]
+        deepest_only: bool = req.media.get("deepest_only", False)
+        threshold: Optional[float] = req.media.get("threshold")
 
         categories = []
 
-        product = get_product(barcode)
         if product:
             predictions = CategoryClassifier(
                 get_taxonomy(TaxonomyType.category.name)
-            ).predict(product, deepest_only)
-            categories = [p.to_dict() for p in predictions]
+            ).predict(product, deepest_only, threshold)
+            categories = [
+                {"value_tag": p.value_tag, "confidence": p.data["confidence"]}
+                for p in predictions
+            ]
 
-        resp.media = {"categories": categories}
+        resp.media = {"neural": categories}
 
 
 class UpdateDatasetResource:
@@ -941,6 +951,8 @@ def get_questions_resource_on_get(
     reserved_barcode: Optional[bool] = req.get_param_as_bool(
         "reserved_barcode", default=False
     )
+    # filter by annotation campaign
+    campaign: Optional[str] = req.get_param("campaign")
 
     # If the device_id is not provided as a request parameter, we use the
     # hash of the IPs as a backup.
@@ -972,6 +984,8 @@ def get_questions_resource_on_get(
         order_by=order_by,
         reserved_barcode=reserved_barcode,
         avoid_voted_on=_get_skip_voted_on(auth, device_id),
+        automatically_processable=False,
+        campaign=campaign,
     )
 
     offset: int = (page - 1) * count
@@ -1155,21 +1169,25 @@ class UnansweredQuestionCollection:
         response: JSONType = {}
         page: int = req.get_param_as_int("page", min_value=1, default=1)
         count: int = req.get_param_as_int("count", min_value=1, default=25)
-        question_type: str = req.get_param("type")
-        value_tag: str = req.get_param("value_tag")
+        insight_type: str = req.get_param("type")
         country: Optional[str] = req.get_param("country")
         server_domain: Optional[str] = req.get_param("server_domain")
+        reserved_barcode: Optional[bool] = req.get_param_as_bool(
+            "reserved_barcode", default=False
+        )
+        campaign: Optional[str] = req.get_param("campaign")
 
-        query_parameters = {
-            "keep_types": [question_type] if question_type else None,
-            "group_by_value_tag": True,
-            "value_tag": value_tag,
-            "limit": count,
-            "country": country,
-            "server_domain": server_domain,
-        }
-
-        get_insights_ = functools.partial(get_insights, **query_parameters)
+        get_insights_ = functools.partial(
+            get_insights,
+            keep_types=[insight_type] if insight_type else None,
+            group_by_value_tag=True,
+            limit=count,
+            country=country,
+            server_domain=server_domain,
+            automatically_processable=False,
+            reserved_barcode=reserved_barcode,
+            campaign=campaign,
+        )
 
         offset: int = (page - 1) * count
         insights = [i for i in get_insights_(limit=count, offset=offset)]
