@@ -12,6 +12,7 @@ from robotoff.utils import get_logger, http_session, jsonl_iter, jsonl_iter_fp
 from robotoff.utils.types import JSONType
 
 from .brand import find_brands
+from .category import find_category
 from .dataclass import OCRParsingException, OCRResult, OCRResultGenerationException
 from .expiration_date import find_expiration_date
 from .image_flag import flag_image
@@ -32,6 +33,7 @@ logger = get_logger(__name__)
 PREDICTION_TYPE_TO_FUNC: Dict[
     str, Callable[[Union[OCRResult, str]], List[Prediction]]
 ] = {
+    PredictionType.category: find_category,
     PredictionType.packager_code: find_packager_codes,
     PredictionType.label: find_labels,
     PredictionType.expiration_date: find_expiration_date,
